@@ -73,7 +73,10 @@ class MapfwBenchmarker:
                 time_func = lambda problem: time_fun(problem,solve_func)
 
                 with Pool() as p:
-                    p.imap(time_func,tqdm(self.problems))
+                    solutions = list(tqdm(p.imap(time_func,self.problems)))
+
+                for p in range(len(self.problems)):
+                    self.problems[p].add_solution(*solutions[p])
 
 
 
